import psycopg2
import psycopg2.extras # For dictionary cursor
import logging
from .db_core import get_db_connection, get_domain # Import from new core module

# Configure basic logging for this module
logger = logging.getLogger(__name__)

def get_failed_urls(limit=100, offset=0) -> list[dict]:
    """Fetches a list of failed URLs."""
    urls = []
    try:
        with get_db_connection() as conn:
            cursor = conn.cursor(cursor_factory=psycopg2.extras.DictCursor)
            cursor.execute("""
                SELECT id, url, domain_name, error_type, failure_count, last_attempt_timestamp
                FROM failed_urls
                ORDER BY last_attempt_timestamp DESC
                LIMIT %s OFFSET %s
            """, (limit, offset))
            rows = cursor.fetchall()
            urls = [dict(row) for row in rows]
    except Exception as e:
        logger.error(f"Failed to fetch failed URLs: {e}", exc_info=True)
    return urls

def get_system_blacklist() -> list[dict]:
    """Fetches the system domain blacklist."""
    domains = []
    try:
        with get_db_connection() as conn:
            cursor = conn.cursor(cursor_factory=psycopg2.extras.DictCursor)
            cursor.execute("SELECT domain_name, reason, added_timestamp FROM system_domain_blacklist ORDER BY domain_name")
            rows = cursor.fetchall()
            domains = [dict(row) for row in rows]
    except Exception as e:
        logger.error(f"Failed to fetch system blacklist: {e}", exc_info=True)
    return domains

def remove_domain_from_system_blacklist(domain_name: str):
    """Removes a domain from the system blacklist."""
    clean_domain = get_domain(domain_name)
    if not clean_domain: return False
    try:
        with get_db_connection() as conn:
            cursor = conn.cursor()
            cursor.execute("DELETE FROM system_domain_blacklist WHERE domain_name = %s", (clean_domain,))
            logger.info(f"Removed domain from system blacklist: {clean_domain}")
            return True
    except Exception as e:
        logger.error(f"Failed to remove domain '{clean_domain}' from system blacklist: {e}", exc_info=True)
        return False
